=======
Autorzy
=======

Programiści
-----------

* Michał Pasternak <michal.dtz@gmail.com>

Bibliotekarze
-------------

* Elżbieta Drożdż <elad@bg.umlub.pl>
* Renata Birska <rbb@bg.umlub.pl>
* Małgorzata Zając <malgorzata.zajac@bg.umlub.pl>
